Struct typos_git_commit::cli::Cli
source · pub struct Cli {Show 13 fields
pub filename: String,
pub minlen: usize,
pub noop: bool,
pub only_list_typos: bool,
pub details: bool,
pub message: String,
pub exclude_file: Option<Vec<String>>,
pub exclude_typo: Option<Vec<String>>,
pub exclude_correction: Option<Vec<String>>,
pub debug: bool,
pub contributors: bool,
pub changelog: bool,
pub completion: Option<Shell>,
}Expand description
This program analyzes a json file produced with typos and makes commits
for each correction.
Fields
filename: Stringtypos file filename to analyze
minlen: usizeminimum length of the typo correction to be considered as correctable automatically.
noop: boolPrints what it will do without doing it
only_list_typos: boolLists typos found in a brief way (does not modify anything)
details: boolDetails output of –only-list-typos option
message: StringMessage to be used in commits. It may use ‘{typo}’ and ‘{correction}’.
exclude_file: Option<Vec<String>>Excludes file from being included in corrections.
exclude_typo: Option<Vec<String>>Excludes typo from being corrected.
exclude_correction: Option<Vec<String>>Excludes a correction from being correctable.
debug: boolDebug options that prints information to know what is going on
contributors: boolprints typos-git-commit contributor’s list
changelog: boolprints typos-git-commit changelog
completion: Option<Shell>prints typos-git-commit bash completion’s shell script
Implementations